Dreamforce 2013 MiniHack Thermostat Challenge - remotes

Dependencies:   C12832_lcd EthernetInterface-ansond-patched HTTPClient-thermostat-remotes LM75B MMA7660 SocketIO WebSocketClient-ThermostatDemo mbed-rtos mbed picojson

Fork of df-2013-minihack-thermostat-complete by MBED_DEMOS

Revision:
1:3faa003ad6e6
Parent:
0:26c48388f725
Child:
3:58f1cc293901
Child:
4:379e9ad21486
--- a/Thermostat.cpp	Tue Nov 05 21:31:01 2013 +0000
+++ b/Thermostat.cpp	Tue Nov 05 22:10:30 2013 +0000
@@ -200,16 +200,15 @@
             if ((*iter).get("led3") != NULL) led3.write(this->translateLEDStatus((*iter).get("led3").get<string>().c_str(),(int)led3));
             if ((*iter).get("led4") != NULL) led4.write(this->translateLEDStatus((*iter).get("led4").get<string>().c_str(),(int)led4));
             if ((*iter).get("reset") != NULL) this->resetDeviceStatus();
-            if ((*iter).get("text") != NULL) this->display((*iter).get("text").get<string>().c_str());
             if ((*iter).get("blink") != NULL) this->blinkAllLEDs();
             
             //
             // 2013 DreamForce MiniHack - add code to look for a "text" message - send its contents to the LCD panel
             // using the this->display(char *) method
             //
             // Answer:
             //
-            if ((*iter).get("text") != NULL) this->display((*iter).get("text").get<string>().c_str()); 
+            if ((*iter).get("text") != NULL) this->displayTextMessage((*iter).get("text").get<string>().c_str()); 
         }
    }
 }
@@ -200,16 +200,15 @@
             //
             // 2013 DreamForce MiniHack - add code to look for a "text" message - send its contents to the LCD panel
-            // using the this->display(char *) method
+            // using the this->displayTextMessage(char *) method
             //
             // Answer: